Learn R Programming

RTN (version 1.10.0)

tni.dpi.filter: Data Processing Inequality (DPI) filter.

Description

This function takes a TNI object and returns the transcriptional network filtered by the data processing inequality algorithm.

Usage

tni.dpi.filter(object, eps=0, verbose=TRUE)

Arguments

object
a processed object of class 'TNI' TNI-class evaluated by the methods tni.permutation and tni.bootstrap.
eps
a single numeric value specifying the threshold under which Aracne algorithm should apply the dpi filter. For additional detail see aracne.
verbose
a single logical value specifying to display detailed messages (when verbose=TRUE) or not (when verbose=FALSE)

Value

a mutual information matrix in the slot "results" containing a dpi-filtered transcriptional network, see 'tn.dpi' option in tni.get.

See Also

TNI-class

Examples

Run this code

data(dt4rtn)

# just a few TFs for quick demonstration!
tfs4test<-c("PTTG1","E2F2","FOXM1","E2F3","RUNX2")

# create a new TNI object
rtni <- new("TNI", gexp=dt4rtn$gexp, transcriptionFactors=dt4rtn$tfs[tfs4test])

## Not run: 
# 
# # preprocessing
# rtni <- tni.preprocess(rtni,gexpIDs=dt4rtn$gexpIDs)
# 
# # permutation analysis (infers the reference/relevance network)
# rtni<-tni.permutation(rtni)
# 
# # dpi filter (infers the transcriptional network)
# rtni<-tni.dpi.filter(rtni)
# 
# ## End(Not run)

Run the code above in your browser using DataLab