Learn R Programming

RTN (version 1.10.0)

tni2tna.preprocess: A preprocessing function for objects of class TNI.

Description

This is a generic function.

Usage

tni2tna.preprocess(object, phenotype=NULL, hits=NULL, phenoIDs=NULL, duplicateRemoverMethod="max", verbose=TRUE)

Arguments

object
a processed object of class 'TNI' TNI-class evaluated by the methods tni.permutation, tni.bootstrap and tni.dpi.filter.
phenotype
a numeric or integer vector of phenotypes named by gene identifiers. Required for gsea, synergy and shadow methods (see tna.gsea1).
hits
a character vector of gene identifiers for those considered as hits. Required for tna.mra and tna.overlap methods.
phenoIDs
an optional 2cols-matrix used to aggregate genes in the 'phenotype' (e.g. probe-to-gene ids; in this case, col 1 should correspond to probe ids).
duplicateRemoverMethod
a single character value specifying the method to remove the duplicates. The current version provides "min" (minimum), "max" (maximum), "average". Further details in 'duplicateRemover' function at the HTSanalyzeR package.
verbose
a single logical value specifying to display detailed messages (when verbose=TRUE) or not (when verbose=FALSE).

See Also

TNI-class TNA-class

Examples

Run this code

data(dt4rtn)

tfs4test<-c("PTTG1","E2F2","FOXM1","E2F3","RUNX2")
rtni <- new("TNI", gexp=dt4rtn$gexp, transcriptionFactors=dt4rtn$tfs[tfs4test])

## Not run: 
# 
# rtni<-tni.preprocess(rtni,gexpIDs=dt4rtn$gexpIDs)
# rtni<-tni.permutation(rtni)
# rtni<-tni.bootstrap(rtni)
# rtni<-tni.dpi.filter(rtni)
# rtna<-tni2tna.preprocess(rtni, phenotype=dt4rtn$pheno, hits=dt4rtn$hits, phenoIDs=dt4rtn$phenoIDs)
# ## End(Not run)

Run the code above in your browser using DataLab